Matches — SoL 3 developers documentation

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »

# Matches

class `sol.models.match.` `Match`(**kwargs)

  A single match.

  This table contains all the matches played in the various turns of a tourney. A match may be between two different competitors or between a competitor and a placeholder, when the number of competitors is odd.

  `board`

    The number of the carromboard this match is played on.

  `caption`(html=None, localized=True)

    A description of the match, made up with the description of each competitor.

  `competitor1`

    First competitor.

  `competitor2`

    Second competitor (may be `None`).

  `description`

    A description of the match, made up with the description of each competitor.

  `idcompetitor1`

    First competitor’s ID.

  `idcompetitor2`

    Second competitor’s ID (possibly None).

  `idmatch`

    Primary key.

  `idtourney`

    Related tourney’s ID.

  `results`()

    Results of this match, comparing competitor’ scores.

    Return a tuple of (winner, loser, netscore).

  `score1`

    First competitor’ score.

  `score2`

    Second competitor’ score.

  `serialize`(serializer, competitors)

    Reduce a single match to a simple dictionary

  `turn`

    Turn of the match.

### Navigation

- index
- modules |
- next |
- previous |
- Dev's documentation »
- SoL modules »
- `sol.models` – SQLAlchemy modelization »